#!/usr/bin/env bash

source /opt/velostrata/velostrata-functions

INITIATOR_FILE=/etc/iscsi/initiatorname.iscsi
VELOS_BCKP_DIR=/etc/velostrata/backup
VELOS_BCKP_FILE=${VELOS_BCKP_DIR}/initiatorname.iscsi.velos_bckp
LOG=/var/tmp/velostrata_online_prep.log

function restart_suse_iscsid
{
	killall -w iscsid
	/sbin/iscsid -c /etc/iscsid.conf
}

source=$1
if [ "${source}" != "ibft" ] && [ "${source}" != "backup" ] ; then
	velos_log_syslog "Unknown source for initiator name: ${source}"
	exit 1
fi

if [ ${source} == "backup" ] ; then
	if [ -f ${VELOS_BCKP_FILE} ] ; then
		velos_log_syslog "Restoring initiator name"
		mv -f ${VELOS_BCKP_FILE} ${INITIATOR_FILE}
		rc=$?
	else
		rc=0
	fi
	exit ${rc}
fi

if [ ! -e /sys/firmware/ibft/initiator/initiator-name ] ; then
	velos_log_syslog "Initiator name was not specified in IBFT"
	exit 0
fi

initiator_name=`cat /sys/firmware/ibft/initiator/initiator-name`
if [ `grep -c ${initiator_name} ${INITIATOR_FILE}` -gt 0 ] ; then
	velos_log_syslog "Initiator name already up-to-date"
	exit 0
fi

if [ ! -e ${VELOS_BCKP_FILE} ] ; then
	mkdir -p ${VELOS_BCKP_DIR}
	cp ${INITIATOR_FILE} ${VELOS_BCKP_FILE}
fi

temp_file=${INITIATOR_FILE}.$$
echo "InitiatorName=${initiator_name}" > ${temp_file}
sync
mv -f ${temp_file} ${INITIATOR_FILE}

if is_suse ; then
	# Restart iscsid in order to re-read the initiator name
	restart_suse_iscsid
fi

exit 0
