#!/bin/bash

source /opt/velostrata/velostrata-functions

SSHCONF=/etc/ssh/sshd_config
SSHBACKUP=/etc/velostrata/backup/sshd_config.pre-gcp

function ensure_public_key_auth() {
	#SSHD is enabled and allows key based authentication.
	#3.3.1. AuthorizedKeysFile .ssh/authorized_keys
	if [ ! -f ${SSHBACKUP} ] ; then
		cp -f ${SSHCONF} ${SSHBACKUP}
	fi
	match_line=$(grep -nm 1 ^Match ${SSHCONF} | cut -d: -f1)
	public_auth=$(cat ${SSHCONF} | grep -v "^#" | grep PubkeyAuthentication | awk '{print $2}')
	if [ -z "${public_auth}" ] ; then
		if [ -z "${match_line}" ] ; then
			echo "#ADDED BY VELOSTRATA" >> $SSHCONF
			echo "PubkeyAuthentication yes" >> $SSHCONF
		else
			sed -i "${match_line}i"\ 'PubkeyAuthentication yes' $SSHCONF
			sed -i "${match_line}i"\ '#ADDED BY VELOSTRATA' $SSHCONF
			match_line=$(( $match_line+2 ))
		fi
	elif [ "${public_auth}" != "yes" ] ; then
		sed -i 's/^PubkeyAuthentication.*/PubkeyAuthentication yes/g' $SSHCONF
	fi

	keys_file=$(cat ${SSHCONF} | grep -v "^#" | grep AuthorizedKeysFile | awk '{print $2}')
	if [ -z "${keys_file}" ] ; then
		if [ -z "${match_line}" ] ; then
			echo "#ADDED BY VELOSTRATA" >> $SSHCONF
			echo "AuthorizedKeysFile .ssh/authorized_keys" >> $SSHCONF
		else
			sed -i "${match_line}i"\ 'AuthorizedKeysFile .ssh/authorized_keys' $SSHCONF
			sed -i "${match_line}i"\ '#ADDED BY VELOSTRATA' $SSHCONF
		fi
	elif [ "${keys_file}" != ".ssh/authorized_keys" ] ; then
		sed -i 's/^AuthorizedKeysFile.*/AuthorizedKeysFile .ssh/authorized_keys/g' $SSHCONF
	fi
}

function revert_sshd_config() {
	if [ -f ${SSHBACKUP} ] ; then
		mv -f ${SSHBACKUP} ${SSHCONF}
	fi
}

function disable_irqbalance() {
	#3.4. Disable or remove the irqbalance daemon.
	if irqbalance >/dev/null; then
		/sbin/chkconfig irqbalance off
		if which systemctl >/dev/null ; then
			systemctl disable irqbalance
		fi
	fi
}

mode=$1
if [ "${mode}" == "origin" ] ; then
	revert_sshd_config
	rm -f /etc/velostrata/actions/bypass/gcp-vm-prep-velos
elif [ "${mode}" == "velos" ] ; then
	ensure_public_key_auth
	disable_irqbalance
	touch /etc/velostrata/actions/bypass/gcp-vm-prep-velos
fi

exit 0
